%% ``The contents of this file are subject to the Erlang Public License,
%% Version 1.1, (the "License"); you may not use this file except in
%% compliance with the License. You should have received a copy of the
%% Erlang Public License along with this software. If not, it can be
%% retrieved via the world wide web at http://www.erlang.org/.
%% 
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and limitations
%% under the License.
%% 
%% The Initial Developer of the Original Code is Ericsson Utvecklings AB.
%% Portions created by Ericsson are Copyright 1999, Ericsson Utvecklings
%% AB. All Rights Reserved.''
%% 
%%     $Id$
%%
%% @doc Erlang language primitives.

-module(erl.lang).

-export([apply/2, apply/3, error/1, error/2, exit/1, throw/1]).


%% @doc Avoid using this function! It exists mainly for internal purposes.
%% <p>FIXME: erl.lang:apply/2 not yet handled by Beam.</p>

apply(Fun, Args) ->
%%%     erl.lang:apply(Fun, Args).		% Built-in function
    erlang:apply(Fun, Args). % FIXME: erl.lang:apply/2 not yet handled by Beam


%% @doc FIXME: erl.lang:apply/2 not yet handled by Beam.

apply(Mod, Name, Args) ->
%%%     erl.lang:apply(Mod, Name, Args).	% Built-in function
    erlang:apply(Mod, Name, Args). % FIXME: erl.lang:apply/3 not yet handled by Beam


%% @spec (Reason::term()) -> term()
%%
%% @doc Raises an exception of class <code>error</code> with associated
%% term <code>Reason</code>. The function call does not return. This
%% exception class signals an unexpected fatal error, and should
%% generally not be caught.
%%
%% @see error/2
%% @see exit/1
%% @see throw/1

error(Reason) ->
    erl.lang:error(Reason).		% Built-in function


%% @spec (Reason::term(), Info::[term()]) -> term()
%%
%% @doc Raises an exception of class <code>error</code> with associated
%% term <code>Reason</code>. The function call does not return. The
%% argument <code>Info</code> provides extra information about the call
%% site (typically the argument list of the containing function call).
%% Whether this information is used or not is implementation dependent.
%%
%% @see error/1

error(Reason, Info) ->
    erl.lang:error(Reason, Info).	% Built-in function


%% @spec (Reason::term()) -> term()
%%
%% @doc Raises an exception of class <code>exit</code> with associated
%% term <code>Reason</code>. The function call does not return. This
%% exception class signals intentional termination of the process, and
%% should generally not be caught.
%%
%% @see error/1
%% @see throw/1

exit(Reason) ->
    erl.lang:exit(Reason).		% Built-in function


%% @spec (Value::term()) -> term()
%%
%% @doc Raises an exception of class <code>throw</code> with associated
%% term <code>Value</code>. The function call does not return. This
%% exception class is used to signal failure or nonlocal return, and is
%% expected to be caught. If a <code>throw</code> is not caught, the
%% process will terminate with an <code>error</code> exception.
%%
%% @see error/1
%% @see exit/1

throw(Value) ->
    erl.lang:throw(Value).		% Built-in function
