%% ``The contents of this file are subject to the Erlang Public License,
%% Version 1.1, (the "License"); you may not use this file except in
%% compliance with the License. You should have received a copy of the
%% Erlang Public License along with this software. If not, it can be
%% retrieved via the world wide web at http://www.erlang.org/.
%% 
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and limitations
%% under the License.
%% 
%% The Initial Developer of the Original Code is Ericsson Utvecklings AB.
%% Portions created by Ericsson are Copyright 1999, Ericsson Utvecklings
%% AB. All Rights Reserved.''
%% 
%%     $Id$
%%
-module(erl.lang.string).

-export([escape/1, is_printable/1, is_string/1, literal/1, literal/2,
	 nocase_equal/2, to_lower/1, to_upper/1]).

-import(erl.lang.char).


%% Tests on strings.

is_string([C | Cs]) ->
    char:is_char(C) andalso is_string(Cs);
is_string([]) ->
    true;
is_string(_) ->
    false.

is_printable([C | Cs]) ->
    char:is_printable(C) andalso is_printable(Cs);
is_printable([]) ->
    true;
is_printable(_) ->
    false.

nocase_equal([C1 | Cs1], [C2 | Cs2]) ->
    char:nocase_equal(C1, C2) andalso nocase_equal(Cs1, Cs2);
nocase_equal([], []) -> true;
nocase_equal(_, _) -> false.


%% Conversion functions.

to_lower(Cs) -> [char:to_lower(C) || C <- Cs].

to_upper(Cs) -> [char:to_upper(C) || C <- Cs].


%% Quoted string/atom literals

literal(S) ->
    literal(S, $").

literal(S, Q) ->
    [Q | literal(S, Q, [Q])].

literal([Q | Cs], Q, T) ->
    [$\\, Q | literal(Cs, Q, T)];	% Handle the quote character
literal([C | Cs], Q, T) ->
    erl.lang.char:escape(C, literal(Cs, Q, T));
literal([], _, T) ->
    T.

escape([C | Cs]) ->
    erl.lang.char:escape(C, escape(Cs));
escape([]) ->
    [].
